# combo - content management system
# Copyright (C) 2017  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import transaction

from combo.apps.maps.models import MapLayer
from .models import Page

def export_site():
    '''Dump site objects to JSON-dumpable dictionnary'''
    return {'pages': Page.export_all_for_json(),
            'map-layers': MapLayer.export_all_for_json()}


def import_site(data, if_empty=False, clean=False):
    if if_empty and (Page.objects.count() or MapLayer.objects.count()):
        return

    if clean:
        MapLayer.objects.all().delete()
        Page.objects.all().delete()

    if isinstance(data, list):
        # old export form with a list of pages, convert it to new dictionary
        # format.
        data = {'pages': data}

    with transaction.atomic():
        MapLayer.load_serialized_objects(data.get('map-layers') or [])

    with transaction.atomic():
        Page.load_serialized_pages(data.get('pages') or [])
